==> kimageannotator_0.3.2.orig.tar.gz: kImageAnnotator-0.3.2/translations/kImageAnnotator_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Упорядочить</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>На верхний слой</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>На слой выше</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>На слой ниже</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>На нижний слой</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Выбрать этот</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Вставить</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Изменить</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationSettings</name>
    <message>
        <source>Color</source>
        <translation>Цвет</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Ширина</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Цвет текста</translation>
    </message>
    <message>
        <source>Font Size</source>
        <translation>Размер шрифта</translation>
    </message>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Видимость обводки и заливки</translation>
    </message>
    <message>
        <source>Starting Number</source>
        <translation>Начальный номер</translation>
    </message>
    <message>
        <source>Blur Radius</source>
        <translation>Радиус размытия</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Crop</source>
        <translation>Обрезать</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>Ш:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>В:</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillTypePicker</name>
    <message>
        <source>No Border and No Fill</source>
        <translation>Без обводки и заливки</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Обводка и заливка</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Обводка без заливки</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Масштабировать изображение</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Сохранять пропорции</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Ширина:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Высота:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Применить</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Пиксели</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Проценты</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Выбор</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Карандаш</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Число</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Маркер прямоугольный</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Маркер эллипсом</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Маркер карандаш</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Стрелка</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Двойная стрелка</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Линия</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Размытие</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Прямоугольник</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Эллипс</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kimageannotator_0.4.0.orig.tar.gz: kImageAnnotator-0.4.0/translations/kImageAnnotator_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Упорядочить</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>На верхний слой</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>На слой выше</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>На слой ниже</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>На нижний слой</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Выбрать этот</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Вставить</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Изменить</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationSettings</name>
    <message>
        <source>Color</source>
        <translation>Цвет</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Ширина</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Цвет текста</translation>
    </message>
    <message>
        <source>Font Size</source>
        <translation>Размер шрифта</translation>
    </message>
    <message>
        <source>Starting Number</source>
        <translation>Начальный номер</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Закрыть остальные</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Закрыть все</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Закрыть все слева</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Закрыть все справа</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Crop</source>
        <translation>Обрезать</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>Ш:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>В:</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation type="unfinished">Видимость обводки и заливки</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation type="unfinished">Обводка и заливка</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation type="unfinished">Обводка без заливки</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation type="unfinished">Без обводки и заливки</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Border</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Масштабировать изображение</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Сохранять пропорции</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Ширина:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Высота:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Применить</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Пиксели</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Проценты</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation type="unfinished">Стикер</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Выбор</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Карандаш</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Число</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Маркер прямоугольный</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Маркер эллипсом</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Маркер карандаш</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Стрелка</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Двойная стрелка</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Линия</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Размытие</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Прямоугольник</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Эллипс</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Числовой указатель</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Стикер</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomIndicator</name>
    <message>
        <source>Zoom Level</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
